#[non_exhaustive]pub enum UpscaleError {
InvalidFactor(u32),
DimensionOverflow {
src: (usize, usize),
factor: u32,
},
DimensionMismatch {
actual: usize,
expected: usize,
},
}Expand description
Errors returned by upscaling setup or execution.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidFactor(u32)
The requested factor is not in the supported set {2, 3, 4}.
DimensionOverflow
Upscaled dimensions would overflow usize.
DimensionMismatch
The image buffer length does not match the declared src_w * src_h.