pub struct ImageView<'a> {
pub data: &'a [u8],
pub width: usize,
pub height: usize,
/* private fields */
}Expand description
Minimal grayscale view for refinement without taking a dependency on image.
Fields
data: &'a [u8]width: usizeheight: usizeImplementations
Sourceimpl<'a> ImageView<'a>
impl<'a> ImageView<'a>
pub fn from_u8_slice( width: usize, height: usize, data: &'a [u8], ) -> Option<ImageView<'a>>
pub fn with_origin( width: usize, height: usize, data: &'a [u8], origin: [i32; 2], ) -> Option<ImageView<'a>>
Sourcepub fn origin(&self) -> [i32; 2]
pub fn origin(&self) -> [i32; 2]
Return the view’s origin in the coordinate system of the response
map / base image. Use Self::with_origin to construct a view
with a non-zero origin.
pub fn supports_patch(&self, cx: i32, cy: i32, radius: i32) -> bool
pub fn sample(&self, gx: i32, gy: i32) -> f32
Sourcepub fn sample_bilinear(&self, gx: f32, gy: f32) -> f32
pub fn sample_bilinear(&self, gx: f32, gy: f32) -> f32
Bilinear sample at subpixel coordinates. Coordinates are in the
view’s external frame (same as Self::sample): origin is
applied, then the sample is clamped to the valid pixel range.